#topsis
This is Implemented by Rishab Chakrabarti 
This is a python package for topsis

## Installation

pip install Topsis_Rishab_102003688

the package can be run using the following command
python R102003688.py <inputfile> <weights> <impacts> <resultfile>

